#
# spec file for package xdg-desktop-portal-wlr
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xdg-desktop-portal-wlr
Version:        0.7.1
Release:        1.3
Summary:        An xdg-desktop-portal backend for wlroots
License:        MIT
Group:          System/Libraries
URL:            https://github.com/emersion/xdg-desktop-portal-wlr
Source0:        %{url}/releases/download/v%{version}/xdg-desktop-portal-wlr-%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{url}/releases/download/v%{version}/xdg-desktop-portal-wlr-%{version}.tar.gz.sig
Source2:        https://emersion.fr/.well-known/openpgpkey/hu/dj3498u4hyyarh35rkjfnghbjxug6b19#/%{name}.keyring
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  scdoc >= 1.9.7
BuildRequires:  pkgconfig(gbm) >= 21.3
BuildRequires:  pkgconfig(inih)
BuildRequires:  pkgconfig(libdrm) >= 2.4.109
BuildRequires:  pkgconfig(libpipewire-0.3) >= 0.3.62
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.24
# Screencasting won't work without pipewire, but it's not a hard dependency.
Recommends:     pipewire >= 0.3.41
Requires:       xdg-desktop-portal

%description
xdg-desktop-portal backend for wlroots.

Make sure the `XDG_CURRENT_DESKTOP` env var is set in the D-Bus user session
to one of the UseIn values in wlr.portal

%prep
%setup -q

%build
%meson -Dsd-bus-provider=libsystemd
%meson_build

%install
%meson_install

%files
%license LICENSE
%doc README.md CONTRIBUTING.md
%{_libexecdir}/%{name}
%{_userunitdir}/%{name}.service
%{_datadir}/dbus-1/services/org.freedesktop.impl.portal.desktop.wlr.service
%{_datadir}/xdg-desktop-portal
%{_datadir}/xdg-desktop-portal/portals
%{_datadir}/xdg-desktop-portal/portals/wlr.portal
%{_mandir}/man5/%{name}.5.gz

%changelog
* Mon Jan 29 2024 Arnav Singh <opensuse@arnavion.dev>
- Update to v0.7.1:
  * Support for 24-bit RGB formats.
  * Various bugfixes.
* Sat Apr 15 2023 Arnav Singh <opensuse@arnavion.dev>
- Use signing key from maintainer's website.
* Sat Apr 15 2023 Arnav Singh <opensuse@arnavion.dev>
- Update to v0.7.0:
  * Support for Screenshot protocol.
  * Report output transforms to PipeWire so that clients can show screencasts
    and screenshots correctly transformed.
  * Partial support for ScreenCast v4 persisted data. Currently this data is
    the name of the selected output, and support must be enabled by setting
    the XDPW_PERSIST_MODE to "transient" or "permanent".
- Add keyring file so that source_validator can verify it.
- Download tarball from release instead of GitHub-packed archive so that
  signature verification works.
* Thu Jun  9 2022 Arnav Singh <opensuse@arnavion.dev>
- Set explicit version bound on libdrm and gbm deps so that build failure
  is obvious on Leap 15.4, etc that have older versions.
* Thu Jun  9 2022 Arnav Singh <opensuse@arnavion.dev>
- Update to 0.6.0:
  * Support for 10-bit color formats.
  * Better performance through supporting DMA-BUFs and PipeWire's swapchain.
* Fri Nov  5 2021 Arnav Singh <opensuse@arnavion.dev>
- Update to 0.5.0
  * Bugfixes and minor internal improvements
* Tue Jun  1 2021 Arnav Singh <opensuse@arnavion.dev>
- Update to 0.4.0:
  * some CLI options have been replaced with config options.
  * quotes in the config file are no longer allowed.
  * Add wlroots to portal manifest UseIn list
  * screenshot: implement `interactive` option
  * screenshot: implement PickColor method
* Sun Apr 18 2021 Arnav Singh <opensuse@arnavion.dev>
- Update to 0.3.0:
  * Add support for config file
  * Add man page
  * Control how many frames are captured per second
  * screencast: add outputchooser with config option
* Mon Feb 15 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.2.0:
  * Add Wayfire to portal UseIn list, as it is also supported
  * Add river to portal UseIn list
  * build: introduce sd-bus-provider option
  * build: add basu as sd-bus provider
  * screencast: prefix macros to avoid conflict with system definitions
  * Revert "Remove unnecessary check from wlr_screencast.c" (#54)
  * core: fix error handling in main
  * core/main: Add static qualifier to internal func
  * core/main: Use EXIT_FAILURE / EXIT_SUCCESS
  * core/main: Clean up option handling
  * systemd: ensure service is stopped on exit of graphical session
  * Fix freeze on skipped frame
  * Remove extraneous whitespace
  * Add --replace flag
  * Destroy wlr_buffer only on quit or error in wlr_screencast.c
  * Only recreate simple_frame on change in wlr_screencast.c
  * munmap simple_frame.data only if needed in wlr_screencast.c
  * Fix log messages in wlr_screencast.c
  * Refresh buffer on change in wlr_screencast.c
  * Change refresh logic and add tests in wlr_screencast.c
  * Add functions to clean simple_buffer.{data,buffer} in wlr_screencast.c
  * Remove unecessary checks in wlr_screencast.c
  * Update to wlr-screencopy-unstable-v1 version 3
* Tue Jul 14 2020 Arnav Singh <opensuse@arnavion.dev>
- Change systemd buildreq to pkgconfig(systemd) for OBS's sake.
* Sat Jul 11 2020 Arnav Singh <opensuse@arnavion.dev>
- Initial packaging of v0.1.0
